@@ -1,4 +1,4 @@
-# Copyright (c) 2011 Simplistix Ltd
+# Copyright (c) 2011-2013 Simplistix Ltd
 # See license.txt for license details.
 """
 Helpers for unit testing when using :mod:`mortar_rdb`
@@ -7,29 +7,28 @@ Helpers for unit testing when using :mod:`mortar_rdb`
 import os
 
 from . import (
-    getSession, declarative_base, drop_tables,
-    registerSession as realRegisterSession
+    get_session, drop_tables,
+    register_session as real_register_session
     )
-from migrate.exceptions import DatabaseAlreadyControlledError
-from migrate.versioning.schema import ControlledSchema
 from sqlalchemy import create_engine
 from sqlalchemy.pool import StaticPool
 
 import mortar_rdb
 
-def registerSession(url=None,
-                    name=u'',
-                    engine=None,
-                    echo=False,
-                    transactional=True,
-                    scoped=True,
-                    config=None,
-                    metadata=None,
-                    extension=None):
+def register_session(url=None,
+                     name=u'',
+                     engine=None,
+                     echo=False,
+                     transactional=True,
+                     scoped=True,
+                     config=None,
+                     metadata=None,
+                     extension=None):
     """
-    This will register a session for testing purposes.
+    This will create a :class:`~sqlalchemy.orm.session.Session` class for
+    testing purposes and register it for later use.
     
-    The calling parameters mirror those of :func:`mortar_rdb.registerSession`
+    The calling parameters mirror those of :func:`mortar_rdb.register_session`
     but if neither `url` nor `engine` is specified then:
 
     - The environment will be consulted for a variable called ``DB_URL``.
@@ -44,6 +43,9 @@ def registerSession(url=None,
 
     If a :class:`~sqlalchemy.schema.MetaData` instance is passed in,
     then all tables within it will be created.
+
+    Unlike the non-testing :class:`~mortar_rdb.register_session`, this will
+    also return an instance of the registered session.
     
     .. warning::
 
@@ -54,16 +56,16 @@ def registerSession(url=None,
 
     if not (url or engine):
         url = os.environ.get('DB_URL')
-        if url is None:
+        if not url:
             # we use a StaticPool so that the in memory databases
             # don't leak between individual tests
             engine = create_engine('sqlite://',
                                    poolclass=StaticPool,
                                    echo=echo)
-            # don't confuse the real registerSession
+            # don't confuse the real register_session
             echo = False
         
-    realRegisterSession(
+    real_register_session(
         url,
         name,
         engine,
@@ -73,22 +75,20 @@ def registerSession(url=None,
         None,
         extension
         )
-    engine = getSession(name).bind
+    session = get_session(name)
+    engine = session.bind
     
     drop_tables(engine)
     
     if config is not None:
         for source in config.sources:
             source.metadata.create_all(engine)
-            ControlledSchema.create(
-                engine,
-                source.repository,
-                source.repository.latest
-                )
 
     if metadata is not None:
         metadata.create_all(engine)
 
+    return session
+
 class TestingBase(object):
     """
     This is a helper class that can either be used to make
@@ -132,24 +132,3 @@ class TestingBase(object):
     
     def __exit__(self,*args):
         self.restore()
-
-def run_migrations(engine,repository,from_,to_):
-    """
-    This test helper is here to help testing migration scripts.
-
-    It will set the version for the supplied repository to the version
-    specified in ``from_`` and then run any migration scripts
-    available to take the version to that specified in ``to_``.
-    """
-    try:
-        ControlledSchema.create(engine,repository,from_)
-    except DatabaseAlreadyControlledError:
-        schema = ControlledSchema(engine,repository)
-        schema.update_repository_table(schema.version,from_)
-
-    schema = ControlledSchema(engine,repository)
-    changeset = schema.changeset(to_)
-    if len(changeset):
-        for ver, change in changeset:
-            nextver = ver + changeset.step
-            schema.runchange(ver, change, changeset.step)
