@@ -1,15 +1,12 @@
-# Copyright (c) 2011 Simplistix Ltd
+# Copyright (c) 2011-2013 Simplistix Ltd
 # See license.txt for license details.
 
 import os
 
-from mortar_rdb.controlled import create_repository
-from mortar_rdb.testing import registerSession, TestingBase, run_migrations
-from mortar_rdb import getSession, declarative_base
-from mortar_rdb.controlled import Config,Source
+from mortar_rdb.testing import register_session, TestingBase
+from mortar_rdb import get_session, declarative_base
+from mortar_rdb.controlled import Config, Source
 from testfixtures.components import TestComponents
-from migrate.exceptions import DatabaseNotControlledError
-from migrate.versioning.schema import ControlledSchema
 from mock import Mock
 from sqlalchemy.pool import StaticPool
 from sqlalchemy.engine.reflection import Inspector
@@ -17,7 +14,7 @@ from sqlalchemy.ext.declarative import declarative_base as sa_declarative_base
 from sqlalchemy.orm import relationship
 from sqlalchemy.schema import Column, ForeignKey
 from sqlalchemy.types import Integer, String
-from testfixtures import Replacer,compare,TempDirectory,OutputCapture
+from testfixtures import Replacer, compare, TempDirectory, OutputCapture
 from unittest import TestCase
 
 class TestRegisterSessionFunctional(TestCase):
@@ -25,7 +22,6 @@ class TestRegisterSessionFunctional(TestCase):
     def setUp(self):
         self.dir = TempDirectory()
         self.components = TestComponents()
-        self.repo = create_repository(self.dir.getpath('repo'),'test')
 
     def tearDown(self):
         self.components.uninstall()
@@ -38,10 +34,10 @@ class TestRegisterSessionFunctional(TestCase):
             id = Column('id', Integer, primary_key=True)
             name = Column('name', String(50))
             
-        registerSession(
+        register_session(
             transactional=False,
-            config=Config(Source(self.repo.path,Model.__table__)))
-        session = getSession()
+            config=Config(Source(Model.__table__)))
+        session = get_session()
         session.add(Model(name='foo'))
         session.commit()
 
@@ -52,11 +48,11 @@ class TestRegisterSessionFunctional(TestCase):
             id = Column('id', Integer, primary_key=True)
             name = Column('name', String(50))
             
-        registerSession(
+        register_session(
             transactional=False,
             metadata=Base.metadata
             )
-        session = getSession()
+        session = get_session()
         session.add(Model(name='foo'))
         session.commit()
 
@@ -66,7 +62,7 @@ class TestRegisterSessionFunctional(TestCase):
             r.replace('os.environ',dict())
             # hoover up the logging ;-)
             with OutputCapture():
-                registerSession(echo=True)
+                register_session(echo=True)
 
     def test_tricky_to_delete(self):
         # respect any DB_URL set here so that
@@ -90,33 +86,34 @@ class TestRegisterSessionFunctional(TestCase):
             id = Column('id', Integer, primary_key=True)
 
         config = Config(Source(
-                self.repo.path,
                 Model1.__table__,
                 Model2.__table__
                 ))
         
         # create in one session
-        registerSession(db_path,name='create',
+        register_session(db_path,name='create',
                         transactional=False,
                         config=config)
         m1 = Model1()
         m2 = Model2()
         m1.model2 = m2
-        session = getSession('create')
+        session = get_session('create')
         session.add(m1)
         session.add(m2)
         session.commit()
         compare(session.query(Model1).count(),1)
         compare(session.query(Model2).count(),1)
+        session.rollback()
 
         # now register another session which should
         # blow the above away
-        registerSession(db_path,name='read',
+        register_session(db_path,name='read',
                         transactional=False,
                         config=config)
-        session = getSession('read')
+        session = get_session('read')
         compare(session.query(Model1).count(),0)
         compare(session.query(Model2).count(),0)
+        session.rollback()
 
     def test_only_some_packages(self):
         Base = sa_declarative_base()
@@ -131,15 +128,14 @@ class TestRegisterSessionFunctional(TestCase):
             id = Column('id', Integer, primary_key=True)
             name = Column('name', String(50))
             
-        registerSession(
+        register_session(
             transactional=False,
-            config=Config(Source(self.repo.path,Model1.__table__)))
+            config=Config(Source(Model1.__table__)))
 
         # only table1 should have been created!
-        # (oh, and the migrate versioning table!)
         compare(
-            [u'migrate_version', u'model1'],
-            Inspector.from_engine(getSession().bind).get_table_names()
+            [u'model1'],
+            Inspector.from_engine(get_session().bind).get_table_names()
             )
             
 class TestRegisterSessionCalls(TestCase):
@@ -148,18 +144,18 @@ class TestRegisterSessionCalls(TestCase):
         self.components = TestComponents()
         self.r = Replacer()
         self.m = Mock()
-        self.r.replace('mortar_rdb.testing.realRegisterSession',
+        self.r.replace('mortar_rdb.testing.real_register_session',
                        self.m.realRegisterSession)
         self.r.replace('mortar_rdb.testing.create_engine',
                        self.m.create_engine)
         # mock out for certainty
         # self.r.replace('mortar_rdb.testing.???',Mock())
         # mock out for table destruction
-        getSession = Mock()
-        bind = getSession.return_value.bind
+        get_session = Mock()
+        bind = get_session.return_value.bind
         bind.dialect.inspector.return_value = inspector = Mock()
         inspector.get_table_names.return_value = ()
-        self.r.replace('mortar_rdb.testing.getSession',getSession)
+        self.r.replace('mortar_rdb.testing.get_session', get_session)
 
     def tearDown(self):
         self.r.restore()
@@ -168,7 +164,7 @@ class TestRegisterSessionCalls(TestCase):
     def test_default_params(self):
         # ie: no DB_URL!
         self.r.replace('os.environ',dict())
-        registerSession()
+        register_session()
         compare([
             ('create_engine',
              ('sqlite://',),
@@ -179,7 +175,7 @@ class TestRegisterSessionCalls(TestCase):
             ],self.m.method_calls)
 
     def test_specified_params(self):
-        registerSession(
+        register_session(
             url='x://',
             name='foo',
             echo=True,
@@ -194,7 +190,7 @@ class TestRegisterSessionCalls(TestCase):
     def test_echo_but_no_url(self):
         # make sure there's no DBURL
         self.r.replace('os.environ',dict())
-        registerSession(echo=True)
+        register_session(echo=True)
         compare([
             ('create_engine',
              ('sqlite://',),
@@ -207,7 +203,7 @@ class TestRegisterSessionCalls(TestCase):
 
     def test_engine_passed(self):
         engine = object()
-        registerSession(
+        register_session(
             engine=engine,
             )
         compare([
@@ -219,18 +215,32 @@ class TestRegisterSessionCalls(TestCase):
         self.r.replace('os.environ',dict(
                 DB_URL = 'x://'
                 ))
-        registerSession()
+        register_session()
         compare([
                 ('realRegisterSession',
                  ('x://', u'', None, False, True, True, None, None), {}),
                 ],self.m.method_calls)
 
+    def test_empty_environment_url(self):
+        self.r.replace('os.environ',dict(
+                DB_URL = ''
+                ))
+        register_session()
+        compare([
+            ('create_engine',
+             ('sqlite://',),
+             {'poolclass': StaticPool,
+              'echo': False}),
+            ('realRegisterSession',
+             ('', u'', self.m.create_engine.return_value, False, True, True, None, None), {}),
+            ],self.m.method_calls)
+
     def test_engine_overrides_environment(self):
         self.r.replace('os.environ',dict(
                 DB_URL = 'x://'
                 ))
         engine = object()
-        registerSession(engine=engine)
+        register_session(engine=engine)
         compare([
                 ('realRegisterSession',
                  (None, u'', engine, False, True, True, None, None), {}),
@@ -239,7 +249,7 @@ class TestRegisterSessionCalls(TestCase):
     def test_extension(self):
         engine = object()
         extension = object()
-        registerSession(engine=engine,extension=extension)
+        register_session(engine=engine,extension=extension)
         compare([
                 ('realRegisterSession',
                  (None, u'', engine, False, True, True, None, extension), {}),
@@ -267,102 +277,3 @@ class TestTestingBase(TestCase):
         self.failIf(b1 is b2)
         self.failIf(b3 is b2)
         self.failUnless(b1 is b3)
-
-ran = []
-
-class TestRunMigrations(TestCase):
-
-    def _create_script(self,repo,name,number):
-        repo.create_script('script '+str(number))
-        self.dir.write((name,'versions',
-                        '00%i_script_%i.py' % (number,number)),"""
-from mortar_rdb.tests.test_testing import ran
-def upgrade(migrate_engine):
-    ran.append('%s-%i')
-""" % (name,number))
-
-    def _check_ran(self,*expected):
-        compare(expected,tuple(ran))
-        
-    def setUp(self):
-        self.dir = TempDirectory()
-        self.components = TestComponents()
-        self.repo = create_repository(self.dir.getpath('repo'),'test')
-        self._create_script(self.repo,'repo',1)
-        self._create_script(self.repo,'repo',2)
-        self._create_script(self.repo,'repo',3)
-        self.repo2 = create_repository(self.dir.getpath('repo2'),'test2')
-        self._create_script(self.repo2,'repo2',1)
-        self._create_script(self.repo2,'repo2',2)
-        registerSession()
-        self.engine = getSession().bind
-        ran[:]=[]
-
-    def tearDown(self):
-        self.components.uninstall()
-        self.dir.cleanup()
-
-    def _check_version(self,repo,expected):
-        try:
-            actual = ControlledSchema(self.engine,repo).version
-        except DatabaseNotControlledError:
-            actual = None
-        compare(expected,actual)
-        
-    def test_from_to(self):
-
-        run_migrations(self.engine,self.repo,1,2)
-
-        self._check_version(self.repo,2)
-        self._check_version(self.repo2,None)
-
-        self._check_ran('repo-2')
-
-    def test_table_already_created(self):
-        ControlledSchema.create(self.engine,self.repo,0)
-        
-        run_migrations(self.engine,self.repo,0,2)
-
-        self._check_version(self.repo,2)
-        self._check_version(self.repo2,None)
-
-        self._check_ran('repo-1', 'repo-2')
-        
-    def test_table_already_created_wrong_version(self):
-        # this is actually the most common case when
-        # unit testing!
-        ControlledSchema.create(self.engine,self.repo,1)
-
-        run_migrations(self.engine,self.repo,0,2)
-
-        self._check_version(self.repo,2)
-        self._check_version(self.repo2,None)
-
-        self._check_ran('repo-1', 'repo-2')
-        
-    def test_multi_step(self):
-        
-        run_migrations(self.engine,self.repo,1,3)
-
-        self._check_version(self.repo,3)
-        self._check_version(self.repo2,None)
-        
-        self._check_ran('repo-2', 'repo-3')
-        
-    def test_to_specified_but_doesnt_exist(self):
-
-        try:
-            run_migrations(self.engine,self.repo,2,4)
-        except KeyError:
-            pass
-        else:
-            # can't use ShouldRaise here due to a bug
-            # in python :-/
-            self.fail('KeyError expected')
-
-        self._check_version(self.repo,2)
-        self._check_version(self.repo2,None)
-
-        # nothing gets run, 'cos the error gets raised
-        # before then.
-        self._check_ran()
